function connect(obj)
% DG1022: Connect to instrument
%
% Cleanup and instrument checking are done here, to allow instrument to be
% plugged-in to PC after creation of instrument object
%
% 2.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)


% load instrument properties
Ps = DG1022.instrumentProperties();

isOk = DG1022.hlp_checkinstallation();
if ~isOk
    error('cannot connect to instrument');
end



%% Get Info about Instrument

% Infos about NI VISA installation - including attached instruments
visaDriver = Ps.VisaDriver;
ViNiInf = instrhwinfo('visa',visaDriver);
Instruments = ViNiInf.ObjectConstructorName;

% Find Instrument with Vendor ID 0x09C4 (ACTiSYS Corp) and PI 0x0400
% which is hopefully a Rigol DG1000 Series
vid = Ps.UsbVid;
pid = Ps.UsbPid;
searchstring = sprintf('USB\\d*::%s::%s',vid,pid);
idx = ~cellfun(@isempty,regexpi(Instruments,searchstring));
if sum(idx)==0
    error('No Rigol DS1000series AWG connected');
elseif sum(idx)~=1
    error(['Multiple Rigol DS1000series AWG found - this has never been'
        'planned']);
end
str = Instruments{idx};
visaId = regexpi(str,'USB\S*INSTR','match','once');


%% Prepare VISA Interface

obj.Interface = visa(visaDriver,visaId);

% close opened interfaces of this instrument
obj_visa = get(obj,'Interface');
name = get(obj_visa,'Name');
instr = instrfind('Name',name,'Status','open');
if ~isempty(instr)
    fclose(instr);
end

% delete all other instances of this instrument
instr = instrfind('Name',name);
if ~isempty(instr)
    idx = ~(instr==obj_visa);
    delete(instr(idx));
end

% Perform interface setting

% EOS read mode makes instrument less prone to
% read-timeouts
set(obj_visa,'EosChar',Ps.EosChar)
set(obj_visa,'EosMode',Ps.EosMode)
obj.Interface.OutputBufferSize = Ps.OutputBufferSize;
obj.Interface.InputBufferSize = Ps.InputBufferSize;
obj.Interface.EoiMode = Ps.EoiMode;

%% Open Interface and Reset

fopen(obj.Interface);
fprintf(obj_visa,'*RST');
end