function Out = getCatalog(obj,memsect)
% DG1022: Get catalog data from Instrument
% Query the names of all user-defined arbitrary waveforms
% downloaded to volatile and non-volatile memory
%
% Out = getcatalog(Visa)
%
% Out = getcatalog(Visa,'nvol') query only non-volatile memory
%
% 2.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.

Visa = hlp_getVisa(obj);

if nargin==1
    % If no further argument, all memory sections will be queried
    memsect = 'all';
end


switch memsect
    case 'all'
        querystr = 'DATA:CAT?';
    case 'nvol'
        querystr = 'DATA:NVOL:CAT?';
        
        % Query how much space is left - if 10 memory spaces are left, memory is
        % totally empty and query 'DATA:NVOL:CAT?' will fail.
        nFree = getFreeMem(obj);
        
        if nFree==10
            Out = {};
            return
        elseif nFree > 10
            error(['Did not expect that - programmer made false assumption' ...
                'about the instrument hardware']);
        end
    otherwise
        error('Invalid memory section');
end



% Query Instrument Memory names
fprintf(Visa,querystr);
pause(0.01);
str = fgets(Visa);

% Fit return string to Matlab cell array
C = regexpi(str,',','split');
C = C(~strcmpi(C,'')); % Remove empty parts
for i = 1:numel(C)
    ci = C{i};
    assert(strcmpi(ci([1 end]),'""'),'Unexpected string format')
    C{i} = ci(2:end-1);
end
Out = C;


