function out =  getDutycycle(Obj,chNo)
% DG1022: Get duty cycle of square waveform
%
% out =  getDutycycle(Obj,chNo)
%
% return value is between 0 and 1
%
% 15.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


Visa = hlp_getVisa(Obj);

% Operation will be hard enough, so let's ensure that there is no error
% pending
clrdevice(Visa);
E = getError(Obj);
if ~(numel(E)==1)
    disp(E)
    error('Instrument Error')
end


%% Interprete channel choice
% Get chSuffix string for scpi command string, get chPrefix for interpretation
% of return argument for choosing the instrument's channel
% For channel 1, no chSuffix is allowed,
% for channel 2, chSuffix is ':CH2'
switch(chNo)
    case 1
        chSuffix = '';
    case 2
        chSuffix = ':CH2';
    otherwise
        error('invalid channelNo');
end


%% Assert this is only with waveform 'Squ'
func = getFunc(Obj,chNo);
if ~strcmpi(func,'Squ')
    error('getDutycycle only makes sense if waveform is ''Squ'' ');
end


%% Send command to instrument
qstr = sprintf('FUNC:SQU:DCYC%s?',chSuffix);
fprintf(Visa,qstr);
pause(0.01);
str = fgets(Visa);
percent = str2double(str);

% Output is value between 0 and 1
out = percent/100;

