function Out = getError(Obj)
% DG1022: Query all pending errors
%
% 15.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


% Setting: Timeout
% Error-query usually is very fast, but the last query before 
% '+0,"No Error" usually ends with a VISA-timeout. To accelerate queries
% of error, he the timeout will be shortened
timeout = 0.5;


Visa = hlp_getVisa(Obj);



% Shorten timeout
oldTimeout = get(Visa,'Timeout');
set(Visa,'Timeout',timeout);

% query Error messages
allOk = '+0,"No Error"';
Out = {};
while(true)
    fprintf(Visa,'SYST:ERR?');
    pause(0.05);
    
    % Long form of "fgets" command prevents Visa timeout message to be
    % printed to the console
    [str,~,~] = fgets(Visa);
    
    str = deblank(str);
    Out = [Out; {str}];
    if strcmp(str,allOk)
        break;
    end
    pause(0.05);
end

% restore old timeout
set(Visa,'Timeout',oldTimeout);