function out =  getFreq(Obj,chNo,keyword)
% DG1022: Get frequency of channel
%
% out =  getFreq(Obj,chNo)
% out =  getFreq(Obj,1,'start')
% out =  getFreq(Obj,1,'stop')
% out =  getFreq(Obj,1,'center')
% out =  getFreq(Obj,1,'span')
%
% 15.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


Visa = hlp_getVisa(Obj);

% Operation will be hard enough, so let's ensure that there is no error
% pending
clrdevice(Visa);
E = getError(Obj);
if ~(numel(E)==1)
    disp(E)
    error('Instrument Error')
end


%% Interprete channel choice
% Get chSuffix string for scpi command string, get chPrefix for interpretation
% of return argument for choosing the instrument's channel
% For channel 1, no chSuffix is allowed,
% for channel 2, chSuffix is ':CH2'
switch(chNo)
    case 1
        % suff
        chSuffix = '';
        chPrefix = '';
    case 2
        chSuffix = ':CH2';
        chPrefix = 'CH2:';
    otherwise
        error('invalid channelNo');
end


%% Interprete keyword
if nargin == 2
    % no keyword
    keyword = 'norm';
end

switch lower(keyword)
    case 'norm'
        modeSuffix = '';
    case {'star','start'}
        modeSuffix = ':STAR';        
    case {'stop'}
        modeSuffix = ':STOP';
    case {'span'}
        modeSuffix = ':SPAN';          
    case {'center','cent'}
        modeSuffix = ':CENT';          
    otherwise
        error('unknown keyword: ''%s'' ',keyword);
end

% Most modes are only allowed by Channel 1:
if chNo == 2 && ~strcmpi(modeSuffix,'')
    error('Channel 2 does not allow this mode: ''%s'' ',keyword);
end


%% Send command to instrument
qstr = sprintf('FREQ%s%s?',modeSuffix,chSuffix);
fprintf(Visa,qstr);
pause(0.01);
str = fgets(Visa);


%% Interprete return value
nPre = numel(chPrefix);
if ~strcmpi(chPrefix(1:nPre),str(1:nPre))
    error('Unexpected return string: ''%s'' ',str);
end
numstr = str(nPre+1:end);
out = str2double(numstr);

