function out =  getFunc(Obj,chNo)
% DG1022: Get function name of channel
%
% out =  getFunc(Obj,chNo)
%
% If a standard waveform (Sin,Squ ...) is active, its name will be
% returned. Also if a user function is active, its name will be returned.
% There must be no user function with same name as a standard function.
%
% 8.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


Visa = hlp_getVisa(Obj);

% Operation will be hard enough, so let's ensure that there is no error
% pending
clrdevice(Visa);
E = getError(Obj);
if ~(numel(E)==1)
    disp(E)
    error('Instrument Error')
end


switch chNo
    case 1
        % Query if a user function is used by CH1
        fprintf(Visa,'FUNC?');
        pause(0.01)
        str = deblank(fgets(Visa));
        isUser1 = strcmpi(str,'CH1:ARB');
        
        if ~isUser1
            % If a builtin waveform is used, pretty-print its name
            C = regexpi(str,':','split');
            assert(strcmpi(C{1},'CH1'),...
                'Expected ''CH1'', got ''%s'' ',C{1});
            
            out = niceWaveformName(C{2});
        else
            % If a user function is used, query if its name
            fprintf(Visa,'FUNC:USER?');
            pause(0.01)
            str = deblank(fgets(Visa));
            if isempty(str)
                error('timeout');
            end
            
            out = niceWaveformName(str);
        end
    case 2
        
        % Query if a user function is used by CH1
        fprintf(Visa,'FUNC:CH2?');
        pause(0.01)
        str = deblank(fgets(Visa));
        isUser = strcmpi(str,'CH2:ARB');
        
        if ~isUser
            % If a builtin waveform is used, pretty-print its name
            C = regexpi(str,':','split');
            assert(strcmpi(C{1},'CH2'),...
                'Expected ''CH2'', got ''%s'' ',C{1});
            
            out = niceWaveformName(C{2});            
        else
            
            % If a user function is used, query if it's THIS one
            fprintf(Visa,'FUNC:USER:CH2?');
            pause(0.01)
            str = deblank(fgets(Visa));
            if isempty(str)
                error('timeout');
            end
            
            out = niceWaveformName(str);
        end
    otherwise
        error('Invalid channel number');
end


end



function out = niceWaveformName(inp)
    % Get nicer printed Waveform name
    Config = DG1022.instrumentProperties;
    Namelist = [Config.BuiltinWaveforms(:); Config.ValidWaveforms(:)];
    idx = strcmpi(Namelist,inp);
    if any(idx)
        out = Namelist{idx};   
    else
        out = inp;
    end
end

