function out =  getVoltage(Obj,chNo,keyword)
% DG1022: Get voltage of any waveform
%
% out =  getVoltage(Obj,chNo)
% out =  getVoltage(Obj,chNo,'high')
% out =  getVoltage(Obj,chNo,'low')
% out =  getVoltage(Obj,chNo,'offset')
% out =  getVoltage(Obj,chNo,'unit')
%
%
% 15.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


Visa = hlp_getVisa(Obj);

% Operation will be hard enough, so let's ensure that there is no error
% pending
clrdevice(Visa);
E = getError(Obj);
if ~(numel(E)==1)
    disp(E)
    error('Instrument Error')
end


%% Interprete channel choice
% Get chSuffix string for scpi command string
% For channel 1, no chSuffix is allowed,
% for channel 2, chSuffix is ':CH2'
switch(chNo)
    case 1
        chSuffix = '';
    case 2
        chSuffix = ':CH2';
    otherwise
        error('invalid channelNo');
end


%% Interprete keyword
if nargin==2
    keyword = 'norm';
end
switch lower(keyword)
    case {'norm','ampl'}
       modeSuffix = '';
    case 'high'
       modeSuffix = ':HIGH';
    case 'low'
       modeSuffix = ':LOW';
    case 'offset'
       modeSuffix = ':OFFS';
    case 'unit'
       modeSuffix = ':UNIT';
    otherwise
        error('Unknown keyword: %s',keyword);
end


%% Send command to instrument
qstr = sprintf('VOLT%s%s?',modeSuffix,chSuffix);
fprintf(Visa,qstr);
pause(0.01);
str = fgets(Visa);


%% Interprete return value
% VOLT? is one of those commands with Channel-prefix (sometimes) if return 
% value is numeric
switch keyword
    case 'unit'
        out = str;
    otherwise
        % Some return values have a prefix for CH2, some not
        idx = strfind(str,'CH2:');
        if ~isempty(idx)
            valstr = str(5:end);
        else
            valstr = str;
        end
        out = str2double(valstr);
end


