function Visa = hlp_getVisa(obj)
% DG1022: Return VISA-Object (helper function)
% 
% Visa = hlp_getVisa(obj)
%
% This helper function allows any subclass of DG1022 to be either
%  - a subclass of visa-class (of instrument control toolbox) or
%  - being any handle class as long as it contains a visa interface object.
%
% This allows direct implementation of methods on Visa classes without
% compatibility problems concerning instrument control class being a
% subclass of Visa
%
% 2.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

if isa(obj,'visa')
    Visa = obj;
else
    switch class(obj)
        case 'DG1022'
            Visa = obj.Interface;
        otherwise 
            error('unknown class - could not determine VISA object');
    end
end
    
