function S = instrumentProperties(varargin)
% Properties of Rigol DG1022 Arbitrary Waverform Generator
% all Instrument specific settings
%
% S = rigol_DG1022_properties()
%
% 28.10.2014 Nicolas

% Driver/Interface
S.VisaDriver = 'ni';
S.VisaId     = 'USB0::0x09C4::0x0400::DG1D163150823::0::INSTR'; % not needed

S.UsbVid = '0x09C4'; % Usb Vendor ID
S.UsbPid = '0x0400'; % Usb Product ID

S.EosChar = 'LF'; %sprintf('\n');
S.EosMode = 'read';
%S.EosMode = 'none'; % TODO: welches passt besser?
S.EoiMode = 'on';

% If all Waveforms fit into the output buffer, this will reduce
% complications.
% max. Samples (CH1) * nChar per Sample + LeadIn + LeadOut =
% 4K * (5 Digits + Comma) + 'DATA:DAC VOLATILE' + \n =
% 4096 * 6 + 17 + 2 = 24595
S.OutputBufferSize = 32768;
S.InputBufferSize = 32768; % nur zum testen


% Timeout of Instrument leaving remote mode
% (queried with stop watch)
S.RemoteTimeout = Inf; % [s]

S.DacMax = 16383;
S.DacMin = 0;


% Waveforms supported by instrument
S.ValidWaveforms = {'Sin','Squ','Ramp','Puls','Nois','Dc','Arb'};

% Instrument Limitations (DG1022)
% (see DG1022 User Guide p. 4-5 (127)
S.Sin.FreqMin   = 1e-6;  % 1Hz
S.Sin.FreqMax   = 20e6;  % 20 MHz
S.Sin.PeriodMin = 50e-9; % -> 20 MHz
S.Sin.PeriodMax = 1e6;   % -> 1 Hz

S.Squ.FreqMin   = 1e-6;  % 1Hz
S.Squ.FreqMax   = 5e6;   % 5MHz
S.Squ.PeriodMin = 200e-9; % -> 5 MHz
S.Squ.PeriodMax = 1e6;    % -> 1 Hz

S.Ramp.SymmMin = 0;     % Percent
S.Ramp.SymmMax = 100;   % Percent
S.Ramp.FreqMin = 1e-6;  % 1 Hz
S.Ramp.FreqMax = 150e3; % 150kHz;

S.Arb.FreqMin = 1e-6;  % 1 Hz
S.Arb.FreqMax = 5e6; % 5MHz;

S.Puls.FreqMin = 500e-6; % 500Hz
S.Puls.FreqMax = 3e6;    % 3MHz


S.BuiltinWaveforms = {'NegRamp','AttALT','AmpALT','StairDown','StairUp',...
    'StairUD','CPulse','PPulse','NPulse','Trapezia','RoundHalf',...
    'AbsSine','AbsSineHalf','SINE_TRA','SINE_VER',...
    'Exp_Rise','ExpFall','Tan','Cot','Sqrt','X^2','Sinc','Gauss',...
    'HaverSine','Lorentz','Dirichlet','GaussPulse','Airy',...
    'Cardiac','Quake','Gamma','Voice','TV','Combin','BandLimited',...
    'StepResponse','Butterworth','Chebyshev1','Chebyshev2',...
    'Boxcar','Barlett','Triang','Blackman','Hamming','Kaiser',...
    'Roundpm','DC','VOLATILE'};





% Argument, if present, is fieldname
if nargin==1
    field = varargin{1};
    assert(ischar(field),'Input must be fieldname');
    assert(isfield(S,field),'Invalid fieldname');
    S = S.(field);
end



end

