function out = readrdf(filename)
% Read *rdf-file of Rigol DG1022 Arbitrary Waveform Generator
%
% out = readrdf(filename);
%
% filename may of may not include the ending *.rdf.
%
% 2.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% The binary waveform data of the instrument is simply raw dac-values
% (14-bit) ORd with 0x8000



% prepare filename (add extension if necessary)
[path,name,ext] = fileparts(filename);
if isempty(ext)
    ext = '.rdf';
elseif strcmpi(ext,'.rdf')
    % OK
else
    error('invalid file ending: %s',ext);
end
filename = fullfile(path,[name ext]);


% read data
fid = fopen(filename,'r');
raw = uint16(zeros(4096,1));
for i = 1:numel(raw)
    ch = fread(fid,1,'*uint16');
    if feof(fid)
        % End of file: did not get the full 4096 words
        warning('Did not get any file delimiter');
        break;
    end
    if ch>=hex2dec('C000')
        % End delimiter: One value left to read
        ch = fread(fid,1,'*uint16');
        raw(i) = ch;
        break;
    end
    raw(i) = ch;
end
fclose(fid);

out = mod(raw(1:i),2^14);
