function setData(Obj,waveformdata)
% DG1022: Write waveform data to instrument (VOLATILE memory)
%
% setData(obj,waveformname,waveformdata)
%
% 9.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


% For this instrument, the total waveform data must fit into one output
% buffer. I did not make it work partitioning waveform date into smaller
% buffer portions. However, this make no practical limitations, since 4096
% samples (as text) fit without problems into 32kB.
% Waveform data can be only sent to "VOLATILE".

Visa = hlp_getVisa(Obj);
outputBufferSize = get(Visa,'OutputBufferSize');
Config = DG1022.instrumentProperties;


% Settings
nSamplesMax = 4096;
waveformname = 'VOLATILE';

%% Pre-Checks

% Operation will be hard enough, so let's ensure that there is no error
% pending
clrdevice(Visa);
E = getError(Obj);
if ~(numel(E)==1)
    disp(E)
    error('Instrument Error')
end


% Check if waveform date fits into DAC values
assert(max(waveformdata)<=Config.DacMax,'Maximum DAC value exceeded');
assert(min(waveformdata)>=Config.DacMin,'Maximum DAC value exceeded');
assert(all(rem(waveformdata,1)==0),'Data must contain only integer values');
assert(numel(waveformdata)<=nSamplesMax,...
    'Data must contain maximal %i samples',nSamplesMax);


% Check if waveform is in use
isUsedCh1 = strcmpi(getFunc(Obj,1),waveformname);
isUsedCh2 = strcmpi(getFunc(Obj,2),waveformname);

if isUsedCh1 || isUsedCh2
    % compose sensible error string
    if isUsedCh1 && isUsedCh2
        str = 'CH1 and CH2';
    elseif isUsedCh1
        str = 'CH1';
    else
        str = 'CH2';
    end
    error('Cannot overwrite waveform which is used by %s',str);
end



%% Prepare new volatile waveform
% Command string will be like 'DATA:DAC VOLATILE,100,200,300,300'
% only strings that fit totally into the output buffer can be send.

strCommand = sprintf('DATA:DAC %s',waveformname);

% Prepare String
s = '';
for i = 2:numel(waveformdata)
    s = [s sprintf(',%i',waveformdata(i))];
end
datastr = sprintf('%s%s',strCommand,s);
nBytesToSend = numel(datastr);

if nBytesToSend>outputBufferSize
    error('Signal is too long for Visa.OutputBufferSize');
end

% Send data
fprintf(Visa,'%s\n',datastr);
pause(4); % Fiddled by hand - can be optimized!
getError(Obj)






end

