function setFunc(Obj,chNo,fcnName)
% DG1022: Set function of channel
%
%  setFunc(Obj,chNo,fcnName)
%
% Set built-in waveforms:
%  setFunc(Obj,chNo,'Sin')
%  setFunc(Obj,chNo,'Chebyshev1');
%
% Set waveforms from memory:
%  setFunc(Obj,chNo,'VOLATILE')
%  setFunc(Obj,chNo,'MY_FCN')
%
% There must be no user function with same name as a standard function.
% 'Arb' is no valid function name. Instead, the concrete name of the
% arbitrary function is required
%
% 14.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


Visa = hlp_getVisa(Obj);

% Operation will be hard enough, so let's ensure that there is no error
% pending
clrdevice(Visa);
E = getError(Obj);
if ~(numel(E)==1)
    disp(E)
    error('Instrument Error')
end


%% Generate Channel suffix
switch chNo
    case 1
        suffix = '';
    case 2
        suffix = ':CH2';
    otherwise
        error('Invalid channel no: %i',chNo);
end

%% Check function name
% 'Arb' is no valid function name
if strcmpi(fcnName,'Arb')
    error([' ''%s'' is no is no valid function name. ' ...
        'For Arbitrary functions, use name of function'],fcnName);
end

%% Standard waveforms (except 'Arb')
Config = DG1022.instrumentProperties;
idx = strcmpi(fcnName,Config.ValidWaveforms(:));
if any(idx)
    waveform = upper(fcnName);
    str = sprintf('APPL:%s%s',waveform,suffix)
    fprintf(Visa,str);
    
    % make sure function has been set correctly
    pause(0.01);
    s = getFunc(Obj,chNo);
    if ~strcmpi(s,waveform)
        error('Could not set waveform: ''%s'' ',waveform);
    else
        return;    
    end
end


%% Built-In waveforms
% contains also 'VOLATILE'
idx = strcmpi(fcnName,Config.BuiltinWaveforms(:));
if any(idx)
    waveform = upper(fcnName);
    str = sprintf('FUNC:USER%s %s',suffix,waveform)
    fprintf(Visa,str);
    
    % make sure function has been set correctly
    pause(0.01);
    s = getFunc(Obj,chNo);
    if ~strcmpi(s,waveform)
        s
        error('Could not set waveform: ''%s'' ',waveform);
    else
        return;    
    end    
end


%% Stored functions
% Request stored waveforms from instrument and set if available
SWaveforms = getCatalog(Obj,'all')
idx = strcmpi(fcnName,SWaveforms);
if any(idx)
    waveform = upper(fcnName);
    str = sprintf('FUNC:USER%s %s',suffix,waveform)
    pause(0.01);
    fprintf(Visa,str);
    
    % make sure function has been set correctly
    pause(0.05);
    s = getFunc(Obj,chNo);
    if ~strcmpi(s,waveform)
        error('Could not set waveform: ''%s'' ',waveform);
    else
        return;    
    end  
end


error('Could not enable function with name ''%s'': Function not found'...
    ,upper(fcnName));
