function setOutput(Obj,ch,onOff)
% DG1022: Set output state of the Instrument ('on' or 'off')
%
% setOutput(obj,ch,'on')
% setOutput(obj,ch,'off')
%
% obj: Instrument/Visa object
% ch: Channel no (1 or 2)
%
% 8.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


Visa = hlp_getVisa(Obj);


% Get suffix string for scpi command string
% For channel 1, no suffix is allowed,
% for channel 2, suffix is ':CH2'
switch(ch)
    case 1
        suffix = '';
    case 2
        suffix = ':CH2';
    otherwise
        error('invalid channelNo');
end

% Send command to instrument
switch lower(onOff)
    case 'on'
        % After Reset, the instrument often does not really set the output 
        % on the first try. However, even then the instrument return 'ON' 
        % upon query. So the only way to ensure output has been set
        % properly is to set twice.
        fprintf(Visa,'OUTP%s ON',suffix);
        pause(0.01);
        fprintf(Visa,'OUTP%s ON',suffix);
    case 'off'
        fprintf(Visa,'OUTP%s OFF',suffix);
    otherwise
        error('Parameter not allowed');
end


% Make sure output has been set correctly
pause(0.01);
s = getOutput(Obj,ch);
if ~strcmpi(s,onOff)
    error(['could not switch output to %s '...
        'returnstring was ''%s'' '],onOff,s);
end