function setPhase(Obj,chNo,value)
% DG1022: Set phase of channel (in degree!)
%
% getPhase(Obj,chNo,valueDeg)
%
% 15.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


Visa = hlp_getVisa(Obj);

% Operation will be hard enough, so let's ensure that there is no error
% pending
clrdevice(Visa);
E = getError(Obj);
if ~(numel(E)==1)
    disp(E)
    error('Instrument Error')
end


%% Interprete channel choice
% Get chSuffix string for scpi command string
% For channel 1, no chSuffix is allowed,
% for channel 2, chSuffix is ':CH2'
switch(chNo)
    case 1
        % suff
        chSuffix = '';
    case 2
        chSuffix = ':CH2';
    otherwise
        error('invalid channelNo');
end


%% Limit values
pMax = 180;
pMin = -180;
if value<pMin || value>pMax
    error('value must be between %d and %d',pMin,pMax);
end


%% Send command to instrument
qstr = sprintf('PHAS%s %i',chSuffix,value);
fprintf(Visa,qstr);
pause(0.01);


%% Verify
v = getPhase(Obj,chNo);
if abs(v-value) > 1e-12
    error('Unexpected voltage value: Expected %d, got %d',...
        value,v);
end
