function setSymmetry(Obj,chNo,value)
% DG1022: Set symmetry parameter of ramp waveform
%
%  setSymmetry(Obj,chNo,value)
%
% value is between 0 and 1
%
% This function only works with 'Ramp' waveform.%
%
% 15.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


Visa = hlp_getVisa(Obj);

% Operation will be hard enough, so let's ensure that there is no error
% pending
clrdevice(Visa);
E = getError(Obj);
if ~(numel(E)==1)
    disp(E)
    error('Instrument Error')
end


%% Interprete channel choice
% Get chSuffix string for scpi command string, get chPrefix for interpretation
% of return argument for choosing the instrument's channel
% For channel 1, no chSuffix is allowed,
% for channel 2, chSuffix is ':CH2'
switch(chNo)
    case 1
        chSuffix = '';
    case 2
        chSuffix = ':CH2';
    otherwise
        error('invalid channelNo');
end


%% Assert this is only with waveform 'Ramp'
func = getFunc(Obj,chNo);
if ~strcmpi(func,'Ramp')
    error('getSymmetry only makes sense if waveform is ''Ramp'' ');
end


%% Assert value is in range
vMin = 0;
vMax = 1;
if value<vMin || value>vMax
    error('Symmetry parameter must be between %f and %f',...
        vMin,vMax);
end


%% Send command to instrument
percent = value*100;
qstr = sprintf('FUNC:RAMP:SYMM%s %s',chSuffix,num2str(percent));
fprintf(Visa,qstr);
pause(0.01);


%% Verify value
v = getSymmetry(Obj,chNo);
if abs(v-value) > 1e-6
    error('Unexpected symmetry parameter value: Expected %d, got %d',...
        value,v);
end
