function setVoltage(Obj,chNo,value,keyword)
% DG1022: Get voltage of any waveform
%
% Set Amplitude (in the current unit):
%  setVoltage(Obj,chNo,value)
%
% Set High- and Low-Value
%  setVoltage(Obj,chNo,value,'high')
%  setVoltage(Obj,chNo,value,'low')
%
% Set Offset:
%  setVoltage(Obj,chNo,value,'offset')
%
% Set Unit: 
%  setVoltage(Obj,chNo,value,'unit')
%
% Warning: voltage will not be limited to sensible values
%
% 
%
%
% 15.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% This implementation needs only a valid Visa Object. No other Visa
% commands than 'fprintf' and 'fgets' are used.


Visa = hlp_getVisa(Obj);

% Operation will be hard enough, so let's ensure that there is no error
% pending
clrdevice(Visa);
E = getError(Obj);
if ~(numel(E)==1)
    disp(E)
    error('Instrument Error')
end


%% Interprete channel choice
% Get chSuffix string for scpi command string
% For channel 1, no chSuffix is allowed,
% for channel 2, chSuffix is ':CH2'
switch(chNo)
    case 1
        chSuffix = '';
    case 2
        chSuffix = ':CH2';
    otherwise
        error('invalid channelNo');
end


%% Interprete keyword
if nargin==3
    keyword = 'norm';
end
switch lower(keyword)
    case {'norm','ampl'}
       modeSuffix = '';
    case 'high'
       modeSuffix = ':HIGH';
    case 'low'
       modeSuffix = ':LOW';
    case 'offset'
       modeSuffix = ':OFFS';
    case 'unit'
       modeSuffix = ':UNIT';
    otherwise
        error('Unknown keyword: %s',keyword);
end


%% Limit value
% not implemented yet


%% Send command to instrument
qstr = sprintf('VOLT%s%s %s',modeSuffix,chSuffix,num2str(value));
fprintf(Visa,qstr);
pause(0.01);


%% Verify
v = getVoltage(Obj,chNo,keyword);
if abs(v-value) > 1e-12
    error('Unexpected voltage value: Expected %d, got %d',...
        value,v);
end

