function [fn] = testwaveform(nSample,no)
% Waveforms for AWG testing purposes
%
% [fn] = testwaveform(nSample,no)
%
% Returns DAC-normalized waveforms which are cyclic, but different in
% subsequent calls. Usage is for testing waveform upload to instrument.
%
% 2.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)


persistent lastno;

nWaveforms = 4;


% assure a new waveform anytime the function is called
if isempty(lastno)
    lastno = 1;
end
if nargin == 1
    no = lastno+1;
end
no = mod(no-1,nWaveforms)+1;
lastno = no;



% Waveforms
switch no
    case 1
        % sine with symmetrically limited caps
        t = 0:2*pi/(nSample-1):2*pi;
        f = sin(t);
        f(f>0.5) = 0.5;
        f(f<-0.5) = -0.5;
    case 2
        % sine with unsymmetrically inward caps
        t = 0:2*pi/(nSample-1):2*pi;
        f = sin(t);
        f(f>0.5) = -f(f>0.5) + 1;
        f(f<-0.75) = -f(f<-0.75)-1.5;
    case 3
        % absolute sine
        t = 0:2*pi/(nSample-1):2*pi;
        f = abs(sin(t));
    case 4
        % Sine with second harmonic
        t = 0:2*pi/(nSample-1):2*pi;
        f = sin(t) + 0.3*sin(3*t);
end



% normalize waveform to dac data
fn = DG1022.normalizewaveform(f);
