function writerdf(filename,data)
% Write *rdf-file of Rigol DG1022 Arbitrary Waveform Generator
%
% writerdf(filename,waveformdata);
%
% filename may of may not include the ending *.rdf.
%
% 2.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)

% The binary waveform data of the instrument is simply raw dac-values
% (14-bit) ORd with 0x8000


% Settings
dacMin = 0;
dacMax = 2^14-1;
nSampleMax = 4096;
nSampleOpt = 4096;



% prepare filename (add extension if necessary)
[path,name,ext] = fileparts(filename);
if isempty(ext)
    ext = '.rdf';
elseif strcmpi(ext,'.rdf')
    % OK
else
    error('invalid file ending: %s',ext);
end
filename = fullfile(path,[name ext]);


% check input data
data = data(:)';
assert(isnumeric(data),'input data must be numeric value');
if (max(data)>dacMax || min(data)<dacMin)
    error('waveform data must be between %i and %i',dacMin,dacMax);
end

if numel(data)>nSampleMax
    error('Number of samples exceeds maximum of %i',nSampleMax');
elseif numel(data)~=nSampleOpt
    warning(['Number of samples does not match optimal sample number' ...
        ' of %i'],nSampleOpt);
end


% write data file
raw = uint16(zeros(4096,1));
nSample = numel(data);
raw(1:nSample) = data + 2^15; % OR with 0x8000
raw(nSample-1) = bitor(raw(nSample-1),hex2dec('C000')); 
fid = fopen(filename,'w+');
for i=1:numel(raw)
    fwrite(fid,raw(i),'*uint16');
end
fclose(fid);

