%% Example: Control DG1022 Arbittary Waveform Generator
% Send Arbitrary Waveform to instrument. 
%
% for detailed information of DG1022 control class:
%
%  doc DG1022
%
% This example can be stepped trough
%
% 15.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)


% Connect to Instrument, reset and wait a bit 
Awg = DG1022();
connect(Awg);
devicereset(Awg);
pause(0.4);

% Query if errors are pending in instrument
getError(Awg)

% Generate an arbitrary waveform. It is recommended to use 4096 samples for
% every waveform. Some waveforms for testing are included. 
% "DG1022.testwaveform" returns different waveforms for each call.
nSamples = 4096;
wav_raw = DG1022.testwaveform(nSamples);

% normalize waveform (set to DAC value between 0 and 2^15)
% ("DG1022.testwaveform" normalizes internally, so this is just for
% description)
wav_norm = DG1022.normalizewaveform(wav_raw);
plot(wav_norm);

% Make shure no channel uses the memory slot 'volatile'
setFunc(Awg,1,'Sin');
setFunc(Awg,2,'Sin');

% Send waveform to memory slot 'volatile'
% this takes a few seconds
setData(Awg,wav_norm)

% Set Channel 1 to 'volatile' memory
setFunc(Awg,1,'volatile');

% Enable Outputs and Sync Signal
setOutput(Awg,1,'On');
setOutput(Awg,2,'On');
setSync(Awg,'On');


% CH2 can not use memory slot volatile. When an arbitrary waveform shall be 
% used for CH2, it must be stored in non-volatile memory.
memname = 'CH2_WAVE1';

% Make sure no channel uses the memory slot 'volatile'
setFunc(Awg,1,'Sin');
setFunc(Awg,2,'Sin');

% Clear memory slot if necessary
S = getCatalog(Awg,'nvol');
if any(strcmpi(S,memname))
    warning('deleting memory slot ''%s'' ',memname);
    deleteData(Awg,memname);
end

% Generate normalized waveform 
nSamples = 4096;
wav_norm2 = DG1022.testwaveform(nSamples);
plot(wav_norm2)

% Send waveform to memory slot 'volatile'
% this takes a few seconds
setData(Awg,wav_norm2);

pause(1);

% Copy waveform to non-volatile memory slot
copyData(Awg,memname);

%setFunc(Awg,1,memname);
%pause(0.5);
%setFunc(Awg,1,'Sin');


setFunc(Awg,2,memname);
setFreq(Awg,2,1000);
setFreq(Awg,1,1000);

% Sometimes, CH2's frequency is not set correctly on the first try, 
% although the value reads back as 1000
setFreq(Awg,2,1000);

% Check waveform
ret = getData(Awg,memname);


