%% Example: Control DG1022 Arbittary Waveform Generator
%
% for detailed information of DG1022 control class:
%
%  doc DG1022
%
% This example can be stepped trough
%
% 15.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)


% Connect to Instrument, reset and wait a bit 
Awg = DG1022();
connect(Awg);
devicereset(Awg);
pause(0.4);

% Query instrument firmware version
getInstrumentModel(Awg)

% Query if errors are pending in instrument
getError(Awg)

% Read some default values after reset (just for info)
Default.freq1 = getFreq(Awg,1);
Default.freq2 = getFreq(Awg,2);
Default.func1 = getFunc(Awg,1);
Default.func2 = getFunc(Awg,2);
disp(Default)

% Set Ch1 waveform
% Ramp, 1.5 kHz, Phase 90, Amplitude 2.2VSS , Offset 1.1V
setFunc(Awg,1,'Ramp');
setFreq(Awg,1,1.5e3);
setPhase(Awg,1,90);
setVoltage(Awg,1,2.2,'ampl');
setVoltage(Awg,1,1.1,'offset');

% Set Ch2 waveform
% Squ, 1.5 kHz, Phase 90, Amplitude 2.2VSS, Offset 0.0V,
% duty cycle 30%
setFunc(Awg,2,'Squ');
setFreq(Awg,2,1.5e3);
setPhase(Awg,2,90);
setVoltage(Awg,2,2.2,'ampl');
setDutycycle(Awg,2,0.3);

% Although both Channels have the same phase, their phase is not aligned.
% This will be done now:
alignPhase(Awg);

% Give the Instrument some time to get ready
pause(0.5);

% Enable Outputs and Sync Signal
setOutput(Awg,1,'On');
setOutput(Awg,2,'On');
setSync(Awg,'On');

% Have a pause and look at the oscilloscope
pause(10);

% When looking at a scope, maybe there's still a sine function.
% sometimes the instrument does not get the first switch of function after
% reset, but the waveform reads as 'Ramp'. On the second try, the correct
% waveform is generated
getFunc(Awg,1)
setFunc(Awg,1,'Ramp')

% Quit when finished
disconnect(Awg);

