%% Read and/or write waveform files for Rigol DG1022
%
% Waveform files for Rigol DG1022 can be read and written from and to an
% USB-Stick with commands "readrdf" and "writerdf", respectively. Afaik,
% these waveform files have the ending *RDF and must be in the root
% directory of the USB-Stick. 
%
% The native resolution of CH1 is 4096 and of CH2 is 1024 samples. However,
% both CH1 and CH2 can read 4096 samples, whereas CH2 will decimate the 
% resolution internally. On the other hand, CH1 sometimes does not
% overwrite his old waveform totally, if the *.RDF-file contains less than
% 4096 samples. Thereby, it is recommended to use always 4096 samples.
%
% This example reads and writes an *.RDF-waveform-file for the DG1022.
%
% 2.11.2014 Nicolas (Check www.dl1dow.de for a more recent version)




% See the result of different numbers of samples.
% The example with only 1024 samples will probable give interesting results
% when it's loaded by the instrument 
nSamples = 1024;
fn = DG1022.testwaveform(nSamples);
plot(fn,'b');
DG1022.writerdf('F:\test1_1024',fn);

hold on

% Taking always 4096 is reliable
nSamples = 4096;
fn = DG1022.testwaveform(nSamples);
plot(fn,'r');
DG1022.writerdf('F:\test2_4096',fn);


% Read a waveform file from USB drive
s = DG1022.readrdf('F:\test1_1024');
plot(s,'c');

hold off